@@ -97,9 +97,14 @@ class Act():
                 self.uwsgi_port = port
                 print str(ip), str(port)
             else:
+                print 'request for %s resulted in a status code of %s' % (uwsgi_uri, h.status_code)
+                print 'the entire header follows:'
+                print h
                 self.uwsgi_ip = None
                 self.uwsgi_port = None
         except:
+            print 'Failure to load the URI at %s' % (uwsgi_uri)
+            print 'Hint: this is probably a stale port.\nTry reloading the Act by touching its .ini file'
             raise
             self.uwsgi_ip = None
             self.uwsgi_port = None
